--[[
	@author: Ziuta
	@date: 13.01.2016
	@version: 1.0.0.0
	@DC: ja_pizgam#6307

	@convert to FS17: 30.10.2016
	@convert to FS19: 22.02.2021	
]]

FillableVehicleInfo = {}

function FillableVehicleInfo.installSpecializations(vehicleTypeManager, specializationManager, modDirectory, modName)
    specializationManager:addSpecialization("fillableInfo", "FillableVehicleInfo", Utils.getFilename("fillableVehicleInfo.lua", modDirectory), nil) -- Nil is important here

    for typeName, typeEntry in pairs(vehicleTypeManager:getVehicleTypes()) do
        if SpecializationUtil.hasSpecialization(FillUnit, typeEntry.specializations) then
			vehicleTypeManager:addSpecialization(typeName, modName .. ".fillableInfo")
        end
    end
end

function FillableVehicleInfo:prerequisitesPresent(specializations)
	return true
end

function FillableVehicleInfo.registerFunctions(vehicleType)
    SpecializationUtil.registerFunction(vehicleType, "actionEventInfo", FillableVehicleInfo.actionEventInfo)
end

function FillableVehicleInfo.registerEventListeners(vehicleType)
	SpecializationUtil.registerEventListener(vehicleType, "onLoad", FillableVehicleInfo)
	SpecializationUtil.registerEventListener(vehicleType, "onRegisterActionEvents", FillableVehicleInfo)
end

function FillableVehicleInfo:onLoad()
	self.spec_fillableInfo = self:fillableInfo_getSpecTable("fillableInfo")
end

function FillableVehicleInfo:onRegisterActionEvents(isActiveForInput, isActiveForInputIgnoreSelection)
    if self.isClient then
        local spec = self.spec_fillableInfo
        self:clearActionEventsTable(spec.actionEvents)
        if isActiveForInputIgnoreSelection then
            local _, actionEventId = self:addActionEvent(spec.actionEvents, InputAction.FILLABLE_INFO, self, FillableVehicleInfo.actionEventInfo, true, true, true, true, nil)
            g_inputBinding:setActionEventTextVisibility(actionEventId, true)
            g_inputBinding:setActionEventTextPriority(actionEventId, GS_PRIO_LOW)
        end
    end
end

function FillableVehicleInfo.actionEventInfo(self, actionName, inputValue, callbackState, isAnalog)	
	for _,vehicle in pairs(g_currentMission.vehicles) do
		local spec = vehicle.spec_fillUnit
		local sowingMachine = vehicle.spec_sowingMachine
		if spec ~= nil and spec.fillUnits ~= nil then		
			local text = "0l (0%) [Unknown]"
				local distance = calcDistanceFrom(vehicle.components[1].node, getCamera())
				if distance < 100 then
					for i, fillUnit in pairs(spec.fillUnits) do
						local index = fillUnit.fillUnitIndex
						local fillLevel = math.floor(vehicle:getFillUnitFillLevel(index))
						local percent = math.floor(vehicle:getFillUnitFillLevelPercentage(index)*100)
						local fillTypeIndex = vehicle:getFillUnitFillType(index)
						local fillType = g_fillTypeManager:getFillTypeByIndex(fillTypeIndex)
						local fillTypeName = fillType.title

						text = fillLevel.."l ("..percent.."%) ["..fillTypeName.."]"

						if sowingMachine ~= nil then
							local selectedSeedFruitType = sowingMachine.seeds[sowingMachine.currentSeed]
							local fillTypeIndex2 = g_fruitTypeManager:getFillTypeIndexByFruitTypeIndex(selectedSeedFruitType)
							local fillType2 = g_fillTypeManager:getFillTypeByIndex(fillTypeIndex2)
							local fillTypeName2 = fillType2.title
							text = fillLevel.."l ("..percent.."%) ["..fillTypeName..": "..fillTypeName2.."]"
						end
						local x, y, z = getWorldTranslation(vehicle.components[1].node)
						Utils.renderTextAtWorldPosition(x, y+3, z, text, getCorrectTextSize(0.02), i*0.02)
					end				
				end	
		end
	end
end